@@ -52,7 +52,7 @@ on_log_select_row (GtkTreeSelection *selection, gpointer user_data)
 		*unknownentry1, *unknownentry2, *modeoptionmenu, *bandoptionmenu,
 		*qsoframe, *framelabel, *awardsentry;
 	gchar *frametext, *entry, *temp;
-	guint i, page, bandenum, modeenum;
+	gint i, page, bandenum, modeenum;
 	GtkTreeModel *model;
 	GtkTreeIter iter;
 	logtype *logw;
