@@ -2,6 +2,7 @@
 
    xlog - GTK+ logging program for amateur radio operators
    Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
+   Copyright (C) 2016 Andy Stewart <kb1oiq@arrl.net>
 
    This file is part of xlog.
 
@@ -340,7 +341,7 @@ on_abutton_clicked (GtkButton * button, gpointer user_data)
 				if (iota != NOT_AN_IOTA)
 				{
 					iota_new_qso(iota, f, qslconfirmed);
-					if ((preferences.awardsiota == 1))
+					if (preferences.awardsiota == 1)
 						update_iotascoring ();
 				}
 				if (qso[LOCATOR] && (strlen(qso[LOCATOR]) > 0))
@@ -588,7 +589,7 @@ on_dbutton_clicked (GtkButton * button, gpointer user_data)
 					if (iota != NOT_AN_IOTA)
 					{
 						iota_del_qso(iota, f, qslin);
-						if ((preferences.awardsiota == 1))
+						if (preferences.awardsiota == 1)
 							update_iotascoring ();
 					}
 					if (locator && (strlen(locator) > 0))
