@@ -328,7 +328,7 @@ on_radiobutton_clicked (GtkButton * button, gpointer user_data)
 	struct rig_caps *rcaps = NULL;
 
 	rigdialog = gtk_dialog_new_with_buttons (_("xlog - select a radio"),
-		GTK_WINDOW(mainwindow), GTK_DIALOG_DESTROY_WITH_PARENT,
+		GTK_WINDOW(mainwindow), GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
 		GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 		GTK_STOCK_OK, GTK_RESPONSE_OK, NULL);
 	gtk_widget_set_size_request (rigdialog, 400, 300);
