@@ -1,7 +1,7 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
-   Copyright (C) 2012 - 2013 Andy Stewart <kb1oiq@arrl.net>
+   Copyright (C) 2012 - 2019 Andy Stewart <kb1oiq@arrl.net>
    Copyright (C) 2001 - 2010 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
@@ -28,6 +28,7 @@
 #include <glib.h>
 #include <stdlib.h>
 #include "cfg.h"
+#include <glib/gprintf.h>
 
 preferencestype preferences;
 extern gchar *xlogdir;
@@ -47,10 +48,12 @@ config_create (void)
 	preferences.longitude = 0.0;
 	preferences.EW = 1;
 	preferences.units = 1;
-	preferences.bands = g_strdup
-("0.136,0.501,1.8,3.5,5.2,7,10,14,18,21,24,28,50,70,144,222,420,902,1240,2300,3300,5650,10000,24000,47000,75500,120000,142000,241000,300000");
-	preferences.modes = g_strdup
-("SSB,CW,FM,AM,PSK31,RTTY,HELL,AMTORFEC,ASCI,ATV,CHIP64,CHIP128,CLO,CONTESTI,DSTAR,DOMINO,DOMINOF,FAX,FMHELL,FSK31,FSK441,GTOR,HELL80,HFSK,JT44,JT4A,JT4B,JT4C,JT4D,JT4E,JT4F,JT4G,JT9,JT9-1,JT9-2,JT9-5,JT9-10,JT9-30,JT65,JT65A,JT65B,JT65C,JT6M,MFSK8,MFSK16,MT63,OLIVIA,PAC,PAC2,PAC3,PAX,PAX2,PCW,PKT,PSK10,PSK63,PSK63F,PSK125,PSKAM10,PSKAM31,PSKAM50,PSKFEC31,PSKHELL,Q15,QPSK31,QPSK63,QPSK125,ROS,RTTYM,SSTV,THRB,THOR,THRBX,TOR,VOI,WINMOR,WSPR");
+	preferences.bands = g_strdup ("0.136,0.472,0.501,1.8,3.5,5,7,10,14,18,21,24,28,50,70,144,222,420,902,1240,2300,3300,5650,10000,24000,47000,75500,120000,142000,241000,300000");
+
+	preferences.modes = g_strndup
+	  ("AM,AMTORFEC,ARDOP,ASCI,ATV,C4FM,CHIP,CHIP64,CHIP128,CLO,CONTESTI,CW,DIGITALVOICE,DOMINO,DOMINOEX,DOMINOF,DSTAR,FAX,FM,FMHELL,FSK31,FSK441,FSKHELL,FSQCALL,FT8,GTOR,HELL,HELL80,HFSK,ISCAT,ISCAT_A,ISCAT_B,JS8,JT4,JT44,JT4A,JT4B,JT4C,JT4D,JT4E,JT4F,JT4G,JT65,JT65A,JT65B,JT65B2,JT65C,JT65C2,JT6M,JT9,JT9_1,JT9_2,JT9_5,JT9_10,JT9_30,JT9A,JT9B,JT9C,JT9D,JT9E,JT9E_FAST,JT9F,JT9F_FAST,JT9G,JT9G_FAST,JT9H,JT9H_FAST,LSB,MFSK,MFSK4,MFSK8,MFSK11,MFSK16,MFSK22,MFSK31,MFSK32,MFSK64,MFSK128,MSK144,MT63,OLIVIA,OLIVIA_4_125,OLIVIA_4_250,OLIVIA_8_250,OLIVIA_8_500,OLIVIA_16_500,OLIVIA_16_1000,OLIVIA_32_1000,OPERA,OPERA_BEACON,OPERA_QSO,PAC,PAC2,PAC3,PAC4,PAX,PAX2,PCW,PKT,PSK,PSK10,PSK31,PSK63,PSK63F,PSK125,PSK250,PSK500,PSK1000,PSK2K,PSKAM10,PSKAM31,PSKAM50,PSKFEC31,PSKHELL,Q15,QPSK31,QPSK63,QPSK125,QPSK250,QPSK500,QRA64,QRA64A,QRA64B,QRA64C,QRA64D,QRA64E,ROS,ROS_EME,ROS_HF,ROS_MF,RTTY,RTTYM,SIM31,SSB,SSTV,T10,THOR,THRB,THRBX,TOR,USB,V4,VOI,WINMOR,WSPR", 1024);
+	preferences.adif3_ok = 1;
+
 	preferences.bandseditbox = 0;
 	preferences.modeseditbox = 0;
 	preferences.bandoptionmenu = 0;
@@ -114,8 +117,8 @@ config_create (void)
 	preferences.logcwidths2[2]=50;
 	preferences.logcwidths2[3]=50;
 	preferences.logcwidths2[4]=100;
-	preferences.logcwidths2[5]=50;
-	preferences.logcwidths2[6]=50;
+	preferences.logcwidths2[5]=75;
+	preferences.logcwidths2[6]=110;
 	preferences.logcwidths2[7]=50;
 	preferences.logcwidths2[8]=50;
 	preferences.logcwidths2[9]=100;
@@ -186,37 +189,38 @@ config_create (void)
 	preferences.scorey = 300;
 	preferences.scorewidth = 500;
 	preferences.scoreheight = 300;
-	preferences.scoringbands = g_new (gint, 30);
-	preferences.scoringbands[0] = 0;
-	preferences.scoringbands[1] = 0;
-	preferences.scoringbands[2] = 1;
-	preferences.scoringbands[3] = 1;
-	preferences.scoringbands[4] = 0;
-	preferences.scoringbands[5] = 1;
-	preferences.scoringbands[6] = 1;
-	preferences.scoringbands[7] = 1;
-	preferences.scoringbands[8] = 1;
-	preferences.scoringbands[9] = 1;
-	preferences.scoringbands[10] = 1;
-	preferences.scoringbands[11] = 1;
-	preferences.scoringbands[12] = 0;
-	preferences.scoringbands[13] = 0;
-	preferences.scoringbands[14] = 0;
-	preferences.scoringbands[15] = 0;
-	preferences.scoringbands[16] = 0;
-	preferences.scoringbands[17] = 0;
-	preferences.scoringbands[18] = 0;
-	preferences.scoringbands[19] = 0;
-	preferences.scoringbands[20] = 0;
-	preferences.scoringbands[21] = 0;
-	preferences.scoringbands[22] = 0;
-	preferences.scoringbands[23] = 0;
-	preferences.scoringbands[24] = 0;
-	preferences.scoringbands[25] = 0;
-	preferences.scoringbands[26] = 0;
-	preferences.scoringbands[27] = 0;
-	preferences.scoringbands[28] = 0;
-	preferences.scoringbands[29] = 0;
+	preferences.scoringbands = g_new (gint, MAX_BANDS);
+	preferences.scoringbands[BAND_2190] = 0;
+	preferences.scoringbands[BAND_630] = 0;
+	preferences.scoringbands[BAND_560] = 1;
+	preferences.scoringbands[BAND_160] = 1;
+	preferences.scoringbands[BAND_80] = 0;
+	preferences.scoringbands[BAND_60] = 1;
+	preferences.scoringbands[BAND_40] = 1;
+	preferences.scoringbands[BAND_30] = 1;
+	preferences.scoringbands[BAND_20] = 1;
+	preferences.scoringbands[BAND_17] = 1;
+	preferences.scoringbands[BAND_15] = 1;
+	preferences.scoringbands[BAND_12] = 1;
+	preferences.scoringbands[BAND_10] = 0;
+	preferences.scoringbands[BAND_6] = 0;
+	preferences.scoringbands[BAND_4] = 0;
+	preferences.scoringbands[BAND_2] = 0;
+	preferences.scoringbands[BAND_125CM] = 0;
+	preferences.scoringbands[BAND_70CM] = 0;
+	preferences.scoringbands[BAND_33CM] = 0;
+	preferences.scoringbands[BAND_23CM] = 0;
+	preferences.scoringbands[BAND_13CM] = 0;
+	preferences.scoringbands[BAND_9CM] = 0;
+	preferences.scoringbands[BAND_6CM] = 0;
+	preferences.scoringbands[BAND_3CM] = 0;
+	preferences.scoringbands[BAND_12HMM] = 0;
+	preferences.scoringbands[BAND_6MM] = 0;
+	preferences.scoringbands[BAND_4MM] = 0;
+	preferences.scoringbands[BAND_2HMM] = 0;
+	preferences.scoringbands[BAND_2MM] = 0;
+	preferences.scoringbands[BAND_1MM] = 0;
+	preferences.scoringbands[BAND_SUBMM] = 0;
 	preferences.distqrb = 0;
 	preferences.awardswac = 0;
 	preferences.awardswas = 0;
@@ -334,12 +338,59 @@ static void config_load_from_keyfile (GKeyFile *file)
 		preferences.units = 1;
 	else
 		preferences.units = preferences.units - 1;
+
+	preferences.adif3_ok = g_key_file_get_integer (file, "general", "adif3_ok", NULL);
+
+	if (preferences.adif3_ok == 0) {
+	  preferences.scoringbands[BAND_2190] = 0;
+	  preferences.scoringbands[BAND_630] = 0;
+	  preferences.scoringbands[BAND_560] = 1;
+	  preferences.scoringbands[BAND_160] = 1;
+	  preferences.scoringbands[BAND_80] = 0;
+	  preferences.scoringbands[BAND_60] = 1;
+	  preferences.scoringbands[BAND_40] = 1;
+	  preferences.scoringbands[BAND_30] = 1;
+	  preferences.scoringbands[BAND_20] = 1;
+	  preferences.scoringbands[BAND_17] = 1;
+	  preferences.scoringbands[BAND_15] = 1;
+	  preferences.scoringbands[BAND_12] = 1;
+	  preferences.scoringbands[BAND_10] = 0;
+	  preferences.scoringbands[BAND_6] = 0;
+	  preferences.scoringbands[BAND_4] = 0;
+	  preferences.scoringbands[BAND_2] = 0;
+	  preferences.scoringbands[BAND_125CM] = 0;
+	  preferences.scoringbands[BAND_70CM] = 0;
+	  preferences.scoringbands[BAND_33CM] = 0;
+	  preferences.scoringbands[BAND_23CM] = 0;
+	  preferences.scoringbands[BAND_13CM] = 0;
+	  preferences.scoringbands[BAND_9CM] = 0;
+	  preferences.scoringbands[BAND_6CM] = 0;
+	  preferences.scoringbands[BAND_3CM] = 0;
+	  preferences.scoringbands[BAND_12HMM] = 0;
+	  preferences.scoringbands[BAND_6MM] = 0;
+	  preferences.scoringbands[BAND_4MM] = 0;
+	  preferences.scoringbands[BAND_2HMM] = 0;
+	  preferences.scoringbands[BAND_2MM] = 0;
+	  preferences.scoringbands[BAND_1MM] = 0;	
+	  preferences.scoringbands[BAND_SUBMM] = 0;
+	} else {
+	  preferences.scoringbands = g_key_file_get_integer_list (file, "scoring", "bands", &len, NULL);
+	}
+
 	preferences.bands = g_key_file_get_string (file, "general", "bands", NULL);
-	if (!preferences.bands) preferences.bands = g_strdup
-("0.136,0.501,1.8,3.5,5.2,7,10,14,18,21,24,28,50,70,144,222,420,902,1240,2300,3300,5650,10000,24000,47000,75500,120000,142000,241000,300000");
+	if ((preferences.adif3_ok == 0) || (!preferences.bands)) {
+	  preferences.bands = g_strdup ("0.136,0.472,0.501,1.8,3.5,5,7,10,14,18,21,24,28,50,70,144,222,420,902,1240,2300,3300,5650,10000,24000,47000,75500,120000,142000,241000,300000");
+	}
+
 	preferences.modes = g_key_file_get_string (file, "general", "modes", NULL);
-	if (!preferences.modes) preferences.modes = g_strdup
-("SSB,CW,FM,AM,PSK31,RTTY,HELL,AMTORFEC,ASCI,ATV,CHIP64,CHIP128,CLO,CONTESTI,DSTAR,DOMINO,DOMINOF,FAX,FMHELL,FSK31,FSK441,GTOR,HELL80,HFSK,JT44,JT4A,JT4B,JT4C,JT4D,JT4E,JT4F,JT4G,JT9,JT9-1,JT9-2,JT9-5,JT9-10,JT9-30,JT65,JT65A,JT65B,JT65C,JT6M,MFSK8,MFSK16,MT63,OLIVIA,PAC,PAC2,PAC3,PAX,PAX2,PCW,PKT,PSK10,PSK63,PSK63F,PSK125,PSKAM10,PSKAM31,PSKAM50,PSKFEC31,PSKHELL,Q15,QPSK31,QPSK63,QPSK125,ROS,RTTYM,SSTV,THRB,THOR,THRBX,TOR,VOI,WINMOR,WSPR");
+	if ((preferences.adif3_ok == 0) || (!preferences.modes)) {
+	  preferences.modes = g_strndup	
+	  ("AM,AMTORFEC,ARDOP,ASCI,ATV,C4FM,CHIP,CHIP64,CHIP128,CLO,CONTESTI,CW,DIGITALVOICE,DOMINO,DOMINOEX,DOMINOF,DSTAR,FAX,FM,FMHELL,FSK31,FSK441,FSKHELL,FSQCALL,FT8,GTOR,HELL,HELL80,HFSK,ISCAT,ISCAT_A,ISCAT_B,JS8,JT4,JT44,JT4A,JT4B,JT4C,JT4D,JT4E,JT4F,JT4G,JT65,JT65A,JT65B,JT65B2,JT65C,JT65C2,JT6M,JT9,JT9_1,JT9_2,JT9_5,JT9_10,JT9_30,JT9A,JT9B,JT9C,JT9D,JT9E,JT9E_FAST,JT9F,JT9F_FAST,JT9G,JT9G_FAST,JT9H,JT9H_FAST,LSB,MFSK,MFSK4,MFSK8,MFSK11,MFSK16,MFSK22,MFSK31,MFSK32,MFSK64,MFSK128,MSK144,MT63,OLIVIA,OLIVIA_4_125,OLIVIA_4_250,OLIVIA_8_250,OLIVIA_8_500,OLIVIA_16_500,OLIVIA_16_1000,OLIVIA_32_1000,OPERA,OPERA_BEACON,OPERA_QSO,PAC,PAC2,PAC3,PAC4,PAX,PAX2,PCW,PKT,PSK,PSK10,PSK31,PSK63,PSK63F,PSK125,PSK250,PSK500,PSK1000,PSK2K,PSKAM10,PSKAM31,PSKAM50,PSKFEC31,PSKHELL,Q15,QPSK31,QPSK63,QPSK125,QPSK250,QPSK500,QRA64,QRA64A,QRA64B,QRA64C,QRA64D,QRA64E,ROS,ROS_EME,ROS_HF,ROS_MF,RTTY,RTTYM,SIM31,SSB,SSTV,T10,THOR,THRB,THRBX,TOR,USB,V4,VOI,WINMOR,WSPR", 1024);
+	  preferences.adif3_ok = 1;
+	} else {
+	  preferences.adif3_ok = preferences.adif3_ok - 1;
+	}
+
 	preferences.typeaheadfind = g_key_file_get_integer (file, "general", "typeaheadfind", NULL);
 	if (preferences.typeaheadfind == 0)
 		preferences.typeaheadfind = 1;
@@ -361,9 +412,10 @@ static void config_load_from_keyfile (GKeyFile *file)
 
 	preferences.areyousure = g_key_file_get_integer (file, "general", "areyousure", NULL);
 	if (preferences.areyousure == 0)
-		preferences.areyousure = 1;
+	  preferences.areyousure = 1;
 	else
-		preferences.areyousure = preferences.areyousure - 1;
+	  preferences.areyousure = preferences.areyousure - 1;
+
 	preferences.viewscoring = g_key_file_get_integer (file, "appearance", "viewscoring", NULL);
 	if (preferences.viewscoring == 0)
 		preferences.viewscoring = 1;
@@ -519,40 +571,6 @@ static void config_load_from_keyfile (GKeyFile *file)
 	preferences.initlastmsg = g_key_file_get_string (file, "keyer", "initial_lastmessage", NULL);
 	if (!preferences.initlastmsg) preferences.initlastmsg = g_strdup ("");
 
-	preferences.scoringbands = g_key_file_get_integer_list (file, "scoring", "bands", &len, NULL);
-	if (!preferences.scoringbands)
-	{
-		preferences.scoringbands[0] = 0;
-		preferences.scoringbands[1] = 0;
-		preferences.scoringbands[2] = 1;
-		preferences.scoringbands[3] = 1;
-		preferences.scoringbands[4] = 0;
-		preferences.scoringbands[5] = 1;
-		preferences.scoringbands[6] = 1;
-		preferences.scoringbands[7] = 1;
-		preferences.scoringbands[8] = 1;
-		preferences.scoringbands[9] = 1;
-		preferences.scoringbands[10] = 1;
-		preferences.scoringbands[11] = 1;
-		preferences.scoringbands[12] = 0;
-		preferences.scoringbands[13] = 0;
-		preferences.scoringbands[14] = 0;
-		preferences.scoringbands[15] = 0;
-		preferences.scoringbands[16] = 0;
-		preferences.scoringbands[17] = 0;
-		preferences.scoringbands[18] = 0;
-		preferences.scoringbands[19] = 0;
-		preferences.scoringbands[20] = 0;
-		preferences.scoringbands[21] = 0;
-		preferences.scoringbands[22] = 0;
-		preferences.scoringbands[23] = 0;
-		preferences.scoringbands[24] = 0;
-		preferences.scoringbands[25] = 0;
-		preferences.scoringbands[26] = 0;
-		preferences.scoringbands[27] = 0;
-		preferences.scoringbands[28] = 0;
-		preferences.scoringbands[29] = 0;
-	}
 	preferences.awardswac = g_key_file_get_integer (file, "scoring", "wac", NULL);
 	if (preferences.awardswac == 0)
 		preferences.awardswac = 0;
@@ -737,12 +755,14 @@ savepreferences (void)
 
 	g_key_file_set_integer (file, "general", "units", preferences.units + 1);
 	g_key_file_set_string (file, "general", "bands", preferences.bands);
+
 	g_key_file_set_string (file, "general", "modes", preferences.modes);
 	g_key_file_set_integer (file, "general", "typeaheadfind", preferences.typeaheadfind + 1);
 	g_key_file_set_integer (file, "general", "remoteadding", preferences.remoteadding + 1);
 	g_key_file_set_integer (file, "general", "distqrb", preferences.distqrb + 1);
 	g_key_file_set_string (file, "general", "openurl", preferences.openurl);
 	g_key_file_set_integer (file, "general", "areyousure", preferences.areyousure + 1);
+	g_key_file_set_integer (file, "general", "adif3_ok", preferences.adif3_ok + 1);
 
 	g_key_file_set_integer (file, "appearance", "viewscoring", preferences.viewscoring + 1);
 	g_key_file_set_integer (file, "appearance", "viewtoolbar", preferences.viewtoolbar + 1);
@@ -796,7 +816,7 @@ savepreferences (void)
 	g_key_file_set_integer (file, "keyer", "speed", preferences.cwspeed);
 	g_key_file_set_string (file, "keyer", "initial_lastmessage", preferences.initlastmsg);
 
-	g_key_file_set_integer_list (file, "scoring", "bands", preferences.scoringbands, 30);
+	g_key_file_set_integer_list (file, "scoring", "bands", preferences.scoringbands, MAX_BANDS);
 	g_key_file_set_integer (file, "scoring", "wac", preferences.awardswac + 1);
 	g_key_file_set_integer (file, "scoring", "was", preferences.awardswas + 1);
 	g_key_file_set_integer (file, "scoring", "waz", preferences.awardswaz + 1);
