@@ -1,7 +1,7 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
-   Copyright (C) 2012 Andy Stewart <kb1oiq@arrl.net>
+   Copyright (C) 2012 - 2017 Andy Stewart <kb1oiq@arrl.net>
    Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
@@ -67,7 +67,7 @@ void on_awards_waz_activate (GtkMenuItem *menuitem, gpointer user_data)
 		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
 		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
 		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
-		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
+		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
 	GtkWidget *treeview = gtk_tree_view_new_with_model (GTK_TREE_MODEL(model));
 	g_object_unref (G_OBJECT (model));
 	gtk_container_add (GTK_CONTAINER (scrolledwindow), treeview);
@@ -75,11 +75,17 @@ void on_awards_waz_activate (GtkMenuItem *menuitem, gpointer user_data)
 	GtkTreeViewColumn *column = gtk_tree_view_column_new_with_attributes
 		("zone", renderer, "text", 0, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
+
 	column = gtk_tree_view_column_new_with_attributes
-		("0.137", renderer, "text", BAND_2190 + 1, NULL);
+		("0.136", renderer, "text", BAND_2190 + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
 	gtk_tree_view_column_set_visible
                 (column, preferences.scoringbands[BAND_2190]);
+	column = gtk_tree_view_column_new_with_attributes
+		("0.472", renderer, "text", BAND_630 + 1, NULL);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
+	gtk_tree_view_column_set_visible
+                (column, preferences.scoringbands[BAND_630]);
 	column = gtk_tree_view_column_new_with_attributes
 		("0.501", renderer, "text", BAND_560 + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
@@ -96,7 +102,7 @@ void on_awards_waz_activate (GtkMenuItem *menuitem, gpointer user_data)
 	gtk_tree_view_column_set_visible
                 (column, preferences.scoringbands[BAND_80]);
 	column = gtk_tree_view_column_new_with_attributes
-		("5.3", renderer, "text", BAND_60 + 1, NULL);
+		("5", renderer, "text", BAND_60 + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
 	gtk_tree_view_column_set_visible
                 (column, preferences.scoringbands[BAND_60]);
