@@ -81,7 +81,7 @@ on_menu_close_activate (GtkMenuItem * menuitem, gpointer user_data)
 				gtk_notebook_remove_page (GTK_NOTEBOOK (mainnotebook), page);
 				set_tabs_menu ();
 				programstate.logwindows--;
-				if (GTK_WIDGET_VISIBLE(scorewindow))
+				if (gtk_widget_get_visible(scorewindow))
 				{
 					fill_scoring_arrays ();
 					update_dxccscoring ();
@@ -108,7 +108,7 @@ on_menu_close_activate (GtkMenuItem * menuitem, gpointer user_data)
 			gtk_notebook_remove_page (GTK_NOTEBOOK (mainnotebook), page);
 			set_tabs_menu ();
 			programstate.logwindows--;
-			if (GTK_WIDGET_VISIBLE(scorewindow))
+			if (gtk_widget_get_visible(scorewindow))
 			{
 				fill_scoring_arrays ();
 				update_dxccscoring ();
