@@ -1,7 +1,7 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
-   Copyright (C) 2012 - 2013 Andy Stewart <kb1oiq@arrl.net>
+   Copyright (C) 2012 - 2017 Andy Stewart <kb1oiq@arrl.net>
    Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
@@ -58,10 +58,10 @@ on_menu_dialogs_activate(GtkMenuItem * menuitem, gpointer user_data)
 		*bu11, *bu12, *bu13, *bu14, *bu15, *bu16, *bu17, *bu18,
 		*b4treeview, *tsvhbox, *bucalc, *busortbydxcc,
 		*groupbycallsignhbox, *groupbycallsignlabel, *groupbycallsignentry,
-		*bb1, *bb2, *bb3, *bb4, *bb5, *bb6, *bb7, *bb8, *bb9, *bb10,
+		*bb1,  *bb2,  *bb3,  *bb4,  *bb5,  *bb6,  *bb7,  *bb8,  *bb9, *bb10,
 		*bb11, *bb12, *bb13, *bb14, *bb15, *bb16, *bb17, *bb18, *bb19,
 		*bb20, *bb21, *bb22, *bb23, *bb24, *bb25, *bb26, *bb27, *bb28,
-		*bb29, *bb30, *vbox3, *bwac, *bwas, *bwaz, *biota, *bloc,
+		*bb29, *bb30, *bb31, *vbox3,*bwac, *bwas, *bwaz, *biota, *bloc,
 		*countrytreeview, *dxcctreeview;
 	gboolean check;
 	gchar *temp;
@@ -304,10 +304,19 @@ on_menu_dialogs_activate(GtkMenuItem * menuitem, gpointer user_data)
 
 	leftvbox = gtk_vbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (framehbox), leftvbox, FALSE, FALSE, 0);
+
 	bb1 = gtk_check_button_new_with_label ("0.136 MHz");
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb1),
 		preferences.scoringbands[BAND_2190]);
 	gtk_box_pack_start (GTK_BOX (leftvbox), bb1, FALSE, FALSE, 0);
+
+	/* Yes, this one is out of order, so to speak.  I didn't want
+	   to renumber ALL of these.....sorry.  AndyS 26-SEPT-2017
+	*/
+	bb31 = gtk_check_button_new_with_label ("0.472 MHz");
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb31),
+		preferences.scoringbands[BAND_630]);
+	gtk_box_pack_start (GTK_BOX (leftvbox), bb31, FALSE, FALSE, 0);
 	bb2 = gtk_check_button_new_with_label ("0.501 MHz");
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb2),
 		preferences.scoringbands[BAND_560]);
@@ -320,7 +329,7 @@ on_menu_dialogs_activate(GtkMenuItem * menuitem, gpointer user_data)
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb4),
 		preferences.scoringbands[BAND_80]);
 	gtk_box_pack_start (GTK_BOX (leftvbox), bb4, FALSE, FALSE, 0);
-	bb5 = gtk_check_button_new_with_label ("5.2 MHz");
+	bb5 = gtk_check_button_new_with_label ("5 MHz");
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bb5),
 		preferences.scoringbands[BAND_60]);
 	gtk_box_pack_start (GTK_BOX (leftvbox), bb5, FALSE, FALSE, 0);
@@ -588,6 +597,8 @@ on_menu_dialogs_activate(GtkMenuItem * menuitem, gpointer user_data)
 
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(bb1));
 		preferences.scoringbands[BAND_2190] = check ? 1 : 0;
+		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(bb31)); /* Yes, out of order... */
+		preferences.scoringbands[BAND_630] = check ? 1 : 0;
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(bb2));
 		preferences.scoringbands[BAND_560] = check ? 1 : 0;
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(bb3));
@@ -750,6 +761,8 @@ on_menu_dialogs_activate(GtkMenuItem * menuitem, gpointer user_data)
 		gtk_tree_view_column_set_visible (gtk_tree_view_get_column
 (GTK_TREE_VIEW(countrytreeview), BAND_2190 + 1), preferences.scoringbands[BAND_2190]);
 		gtk_tree_view_column_set_visible (gtk_tree_view_get_column
+(GTK_TREE_VIEW(countrytreeview), BAND_630 + 1), preferences.scoringbands[BAND_630]);
+		gtk_tree_view_column_set_visible (gtk_tree_view_get_column
 (GTK_TREE_VIEW(countrytreeview), BAND_560 + 1), preferences.scoringbands[BAND_560]);
 		gtk_tree_view_column_set_visible (gtk_tree_view_get_column
 (GTK_TREE_VIEW(countrytreeview), BAND_160 + 1), preferences.scoringbands[BAND_160]);
@@ -812,6 +825,8 @@ on_menu_dialogs_activate(GtkMenuItem * menuitem, gpointer user_data)
 		gtk_tree_view_column_set_visible (gtk_tree_view_get_column
 (GTK_TREE_VIEW(dxcctreeview), BAND_2190), preferences.scoringbands[BAND_2190]);
 		gtk_tree_view_column_set_visible (gtk_tree_view_get_column
+(GTK_TREE_VIEW(dxcctreeview), BAND_630), preferences.scoringbands[BAND_630]);
+		gtk_tree_view_column_set_visible (gtk_tree_view_get_column
 (GTK_TREE_VIEW(dxcctreeview), BAND_560), preferences.scoringbands[BAND_560]);
 		gtk_tree_view_column_set_visible (gtk_tree_view_get_column
 (GTK_TREE_VIEW(dxcctreeview), BAND_160), preferences.scoringbands[BAND_160]);
