@@ -1,6 +1,7 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
+   Copyright (C) 2017 Andy Stewart <kb1oiq@arrl.net>
    Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
@@ -188,7 +189,8 @@ static GtkActionEntry entries[] =
   { "Dupe Check", GTK_STOCK_COPY, N_("Dupe Check..."), "<control><shift>C", "Check the log(s) for dupes", G_CALLBACK(on_menu_dupecheck_activate) },
   { "Log Editor", GTK_STOCK_PROPERTIES, N_("Log Editor"), "<control><shift>E", "Format fields in the log", G_CALLBACK(on_menu_logeditor_activate) },
   { "Trace Hamlib", GTK_STOCK_EXECUTE, N_("Trace Hamlib"), "<control><shift>T", "Show hamlib debugging output", G_CALLBACK(on_trace_hamlib_activate) },
-  { "Sort", GTK_STOCK_SORT_ASCENDING, N_("Sort by Date"), "<control><shift>O", "Sort log by date", G_CALLBACK(on_sort_log_activate) },
+  { "Sort Date", GTK_STOCK_SORT_ASCENDING, N_("Sort by Date"), "<control><shift>O", "Sort log by date", G_CALLBACK(on_sort_log_date_activate) },
+  { "Sort Call", GTK_STOCK_SORT_ASCENDING, N_("Sort by Callsign"), "<control><shift>R", "Sort log by callsign", G_CALLBACK(on_sort_log_callsign_ascending_activate) },
   { "Awards", GTK_STOCK_INDEX, N_("Awards"), "", "Overview of Awards", NULL },
   { "DXCC", GTK_STOCK_INFO, "DXCC", "<control>1", "DXCC worked/confirmed", G_CALLBACK(on_awards_dxcc_activate) },
   { "WAC", GTK_STOCK_INFO, "WAC", "<control>2", "WAC worked/confirmed", G_CALLBACK(on_awards_wac_activate) },
@@ -281,7 +283,8 @@ static const char *ui_description =
 "		<menuitem action='DXCC Check'/>"
 "		<menuitem action='Log Editor'/>"
 "		<menuitem action='Trace Hamlib'/>"
-"		<menuitem action='Sort'/>"
+"		<menuitem action='Sort Date'/>"
+"               <menuitem action='Sort Call'/>"
 "		<separator name='sep6'/>"
 "		<menu action='Awards'>"
 "		  <menuitem action='DXCC'/>"
