@@ -161,7 +161,7 @@ on_menu_open_activate (GtkMenuItem * menuitem, gpointer user_data)
 				set_qsoframe (logwindow);
 				set_tabs_menu ();
 
-				if (GTK_WIDGET_VISIBLE(scorewindow))
+				if (gtk_widget_get_visible(scorewindow))
 				{
 					fill_scoring_arrays ();
 					update_dxccscoring ();
