@@ -113,7 +113,8 @@ void
 activate_bandoption_by_enum (GtkWidget *combo, gchar *prefs, guint enumband)
 {
 	gchar **spl = NULL;
-	guint index = 0, prefsband;
+	guint index = 0;
+	gint prefsband;
 
 	spl = g_strsplit (prefs, ",", 0);
 	for (;;)
