@@ -71,6 +71,7 @@
 #endif
 
 gint statusbartimer;
+
 extern GtkWidget *mainwindow, *keyerwindow, *b4window, *scorewindow;
 extern preferencestype preferences;
 extern programstatetype programstate;
@@ -832,3 +833,17 @@ qslreceived(gchar *in)
 	if (in && (!g_ascii_strcasecmp (in, "x") || !g_ascii_strcasecmp (in, "y"))) return TRUE;
 	return FALSE;
 }
+
+gint num_qsos_to_export;
+
+gint
+get_num_qsos_to_export(void)
+{
+  return num_qsos_to_export;
+}
+
+void 
+save_num_qsos_to_export(gint num)
+{
+  num_qsos_to_export = num;
+}
